@@ -2,9 +2,13 @@
 # Copyright: Dmitry Shachnev 2012
 # License: GNU GPL v2 or higher
 
-from ReText import *
+from ReText import QtCore, QtGui, DOCTYPE_NONE, DOCTYPE_MARKDOWN, DOCTYPE_REST, DOCTYPE_HTML
 import re
 
+Qt = QtCore.Qt
+(QFont, QSyntaxHighlighter, QTextCharFormat) = (QtGui.QFont, QtGui.QSyntaxHighlighter,
+ QtGui.QTextCharFormat)
+
 class ReTextHighlighter(QSyntaxHighlighter):
 	dictionary = None
 	docType = DOCTYPE_NONE
@@ -34,6 +38,7 @@ class ReTextHighlighter(QSyntaxHighlighter):
 			DOCTYPE_REST: (4, 6, 14, 15),
 			DOCTYPE_HTML: (0, 1, 2, 3)
 		}
+		# Syntax highlighter
 		if self.docType in patternsDict:
 			for number in patternsDict[self.docType]:
 				pattern = patterns[number]
@@ -47,8 +52,8 @@ class ReTextHighlighter(QSyntaxHighlighter):
 					charFormat.setFontUnderline(pattern[4])
 				for match in re.finditer(pattern[0], text):
 					self.setFormat(match.start(), match.end() - match.start(), charFormat)
+		# Spell checker
 		if self.dictionary:
-			text = convertToUnicode(text)
 			charFormat = QTextCharFormat()
 			charFormat.setUnderlineColor(Qt.red)
 			charFormat.setUnderlineStyle(QTextCharFormat.SpellCheckUnderline)
