@@ -5,6 +5,7 @@
 import os
 import sys
 import shutil
+from functools import wraps
 from markups.web import WebLibrary
 from ReText import app_version
 
@@ -21,26 +22,32 @@ if not os.path.exists(templatesDir):
 if not os.path.exists(templatesDir):
 	templatesDir = "/usr/local/share/wpgen/"
 
+def handleErrors(functionIn):
+	@wraps(functionIn)
+	def functionOut(*args, **kwds):
+		try:
+			return functionIn(*args, **kwds)
+		except IOError as e:
+			print('Exception occured: %s' % e, file=sys.stderr)
+	return functionOut
+
+@handleErrors
 def wpInit():
 	if not os.path.exists("html"):
 		os.mkdir("html")
 	shutil.copy(templatesDir+"template_Default.html", "template.html")
 	shutil.copy(templatesDir+"style_Default.css", "html/style.css")
 
+@handleErrors
 def wpUpdate(pages):
 	wl = WebLibrary(app_data=app_data)
 	for page in pages:
-		try:
-			wl.update(page)
-		except IOError as e:
-			print(e)
+		wl.update(page)
 
+@handleErrors
 def wpUpdateAll():
 	wl = WebLibrary(app_data=app_data)
-	try:
-		wl.update_all()
-	except IOError as e:
-		print(e)
+	wl.update_all()
 
 def wpUseStyle(styleName):
 	if os.path.exists(templatesDir+"style_%s.css" % styleName):
