@@ -281,7 +281,8 @@ class ReTextWindow(QMainWindow):
 		menuFormat.addAction(self.actionBold)
 		menuFormat.addAction(self.actionItalic)
 		menuFormat.addAction(self.actionUnderline)
-		menuEdit.addAction(self.actionWebKit)
+		if QtCore.__package__ != 'PySide': # PYSIDE-213
+			menuEdit.addAction(self.actionWebKit)
 		menuEdit.addSeparator()
 		menuEdit.addAction(self.actionViewHtml)
 		menuEdit.addAction(self.actionLivePreview)
@@ -408,6 +409,8 @@ class ReTextWindow(QMainWindow):
 		urlstr = url.toString()
 		if urlstr.startswith('file://') or ':/' not in urlstr:
 			self.previewBoxes[self.ind].load(url)
+		elif urlstr.startswith('#'):
+			self.previewBoxes[self.ind].page().mainFrame().scrollToAnchor(urlstr[1:])
 		elif urlstr.startswith('about:blank#'):
 			self.previewBoxes[self.ind].page().mainFrame().scrollToAnchor(urlstr[12:])
 		else:
