@@ -1,14 +1,87 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS><TS version="2.0" language="pl_PL" sourcelanguage="">
 <context>
-    <name>LocaleDialog</name>
+    <name>ConfigDialog</name>
     <message>
-        <location filename="window.py" line="17"/>
-        <source>Enter locale name (example: en_US)</source>
-        <translation>Wprowadź kod lokalizacji (np. en_US)</translation>
+        <location filename="config.py" line="24"/>
+        <source>Behavior</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="22"/>
+        <location filename="config.py" line="24"/>
+        <source>Automatically save documents</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Restore window geometry</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Restore live preview state</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Open external links in ReText window</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Open unknown files in plain text mode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Editor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Highlight current line</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Show line numbers</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Tab key inserts spaces</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Tabulation width</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Display right margin at column</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Interface</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Icon theme name</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>LocaleDialog</name>
+    <message>
+        <location filename="dialogs.py" line="34"/>
+        <source>Enter locale name (example: en_US)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="dialogs.py" line="39"/>
         <source>Set as default</source>
         <translation type="unfinished"></translation>
     </message>
@@ -16,389 +89,404 @@
 <context>
     <name>ReTextWindow</name>
     <message>
-        <location filename="window.py" line="71"/>
+        <location filename="window.py" line="92"/>
         <source>File toolbar</source>
         <translation>Pasek pliku</translation>
     </message>
     <message>
-        <location filename="window.py" line="73"/>
+        <location filename="window.py" line="94"/>
         <source>Edit toolbar</source>
         <translation>Pasek edycji</translation>
     </message>
     <message>
-        <location filename="window.py" line="75"/>
+        <location filename="window.py" line="96"/>
         <source>Search toolbar</source>
         <translation>Pasek wyszukiwania</translation>
     </message>
     <message>
-        <location filename="window.py" line="80"/>
+        <location filename="window.py" line="100"/>
         <source>New</source>
         <translation>Nowy</translation>
     </message>
     <message>
-        <location filename="window.py" line="83"/>
+        <location filename="window.py" line="103"/>
         <source>Open</source>
         <translation>Otwórz</translation>
     </message>
     <message>
-        <location filename="window.py" line="86"/>
+        <location filename="window.py" line="109"/>
         <source>Save</source>
         <translation>Zapisz</translation>
     </message>
     <message>
-        <location filename="window.py" line="90"/>
+        <location filename="window.py" line="113"/>
         <source>Save as</source>
         <translation>Zapisz jako</translation>
     </message>
     <message>
-        <location filename="window.py" line="92"/>
+        <location filename="window.py" line="115"/>
         <source>Print</source>
         <translation>Drukuj</translation>
     </message>
     <message>
-        <location filename="window.py" line="95"/>
+        <location filename="window.py" line="118"/>
         <source>Print preview</source>
         <translation>Podgląd wydruku</translation>
     </message>
     <message>
-        <location filename="window.py" line="97"/>
+        <location filename="window.py" line="120"/>
         <source>View HTML code</source>
         <translation>Zobacz źródło HTML</translation>
     </message>
     <message>
-        <location filename="window.py" line="98"/>
+        <location filename="window.py" line="121"/>
         <source>Change default font</source>
         <translation>Zmień domyślną czcionkę</translation>
     </message>
     <message>
-        <location filename="window.py" line="99"/>
+        <location filename="window.py" line="122"/>
         <source>Find text</source>
         <translation>Znajdź tekst</translation>
     </message>
     <message>
-        <location filename="window.py" line="104"/>
+        <location filename="window.py" line="126"/>
         <source>Preview</source>
         <translation>Podgląd</translation>
     </message>
     <message>
-        <location filename="window.py" line="113"/>
+        <location filename="window.py" line="135"/>
         <source>Live preview</source>
         <translation>Podgląd na żywo</translation>
     </message>
     <message>
-        <location filename="window.py" line="115"/>
+        <location filename="window.py" line="137"/>
         <source>Fullscreen mode</source>
         <translation>Pełny ekran</translation>
     </message>
     <message>
-        <location filename="window.py" line="121"/>
+        <location filename="window.py" line="145"/>
         <source>Quit</source>
         <translation>Zakończ</translation>
     </message>
     <message>
-        <location filename="window.py" line="124"/>
+        <location filename="window.py" line="148"/>
         <source>Undo</source>
         <translation>Cofnij</translation>
     </message>
     <message>
-        <location filename="window.py" line="126"/>
+        <location filename="window.py" line="150"/>
         <source>Redo</source>
         <translation>Ponów</translation>
     </message>
     <message>
-        <location filename="window.py" line="128"/>
+        <location filename="window.py" line="152"/>
         <source>Copy</source>
         <translation>Skopiuj</translation>
     </message>
     <message>
-        <location filename="window.py" line="130"/>
+        <location filename="window.py" line="154"/>
         <source>Cut</source>
         <translation>Wytnij</translation>
     </message>
     <message>
-        <location filename="window.py" line="132"/>
+        <location filename="window.py" line="156"/>
         <source>Paste</source>
         <translation>Wklej</translation>
     </message>
     <message>
-        <location filename="window.py" line="141"/>
+        <location filename="window.py" line="166"/>
         <source>Enable</source>
         <translation>Włącz</translation>
     </message>
     <message>
-        <location filename="window.py" line="142"/>
+        <location filename="window.py" line="167"/>
         <source>Set locale</source>
         <translation>Ustaw język</translation>
     </message>
     <message>
-        <location filename="window.py" line="143"/>
+        <location filename="window.py" line="168"/>
         <source>Plain text</source>
         <translation>Tryb tekstowy</translation>
     </message>
     <message>
-        <location filename="window.py" line="145"/>
+        <location filename="window.py" line="169"/>
         <source>Use WebKit renderer</source>
         <translation>Używaj silnika WebKit</translation>
     </message>
     <message>
-        <location filename="window.py" line="151"/>
+        <location filename="window.py" line="171"/>
         <source>Generate webpages</source>
         <translation>Generuj stronę internetową</translation>
     </message>
     <message>
-        <location filename="window.py" line="152"/>
+        <location filename="window.py" line="172"/>
         <source>Show</source>
         <translation>Pokaż</translation>
     </message>
     <message>
-        <location filename="window.py" line="153"/>
+        <location filename="window.py" line="173"/>
         <source>Next</source>
         <translation>Następny</translation>
     </message>
     <message>
-        <location filename="window.py" line="155"/>
+        <location filename="window.py" line="175"/>
         <source>Previous</source>
         <translation>Poprzedni</translation>
     </message>
     <message>
-        <location filename="window.py" line="157"/>
+        <location filename="window.py" line="177"/>
         <source>Get help online</source>
         <translation>Pomoc online</translation>
     </message>
     <message>
-        <location filename="window.py" line="158"/>
+        <location filename="window.py" line="178"/>
         <source>About %s</source>
         <comment>Example of final string: About ReText</comment>
         <translation>O %s</translation>
     </message>
     <message>
-        <location filename="window.py" line="166"/>
+        <location filename="window.py" line="182"/>
         <source>About Qt</source>
         <translation>O Qt</translation>
     </message>
     <message>
-        <location filename="window.py" line="187"/>
+        <location filename="window.py" line="202"/>
         <source>Bold</source>
         <translation>Pogrubienie</translation>
     </message>
     <message>
-        <location filename="window.py" line="189"/>
+        <location filename="window.py" line="204"/>
         <source>Italic</source>
         <translation>Kursywa</translation>
     </message>
     <message>
-        <location filename="window.py" line="191"/>
+        <location filename="window.py" line="206"/>
         <source>Underline</source>
         <translation>Podkreślenie</translation>
     </message>
     <message>
-        <location filename="window.py" line="199"/>
+        <location filename="window.py" line="214"/>
         <source>Tags</source>
         <translation>Tagi</translation>
     </message>
     <message>
-        <location filename="window.py" line="203"/>
+        <location filename="window.py" line="218"/>
         <source>Symbols</source>
         <translation>Symbole</translation>
     </message>
     <message>
-        <location filename="window.py" line="217"/>
+        <location filename="window.py" line="231"/>
         <source>File</source>
         <translation>Plik</translation>
     </message>
     <message>
-        <location filename="window.py" line="218"/>
+        <location filename="window.py" line="232"/>
         <source>Edit</source>
         <translation>Edycja</translation>
     </message>
     <message>
-        <location filename="window.py" line="219"/>
+        <location filename="window.py" line="233"/>
         <source>Help</source>
         <translation>Pomoc</translation>
     </message>
     <message>
-        <location filename="window.py" line="222"/>
+        <location filename="window.py" line="236"/>
         <source>Open recent</source>
         <translation>Otwórz ostatnie</translation>
     </message>
     <message>
-        <location filename="window.py" line="225"/>
+        <location filename="window.py" line="239"/>
         <source>Directory</source>
         <translation>Katalog</translation>
     </message>
     <message>
-        <location filename="window.py" line="232"/>
+        <location filename="window.py" line="247"/>
         <source>Export</source>
         <translation>Eksportuj</translation>
     </message>
     <message>
-        <location filename="window.py" line="253"/>
+        <location filename="window.py" line="269"/>
         <source>Spell check</source>
         <translation>Sprawdzanie pisowni</translation>
     </message>
     <message>
-        <location filename="window.py" line="261"/>
-        <source>Default editing mode</source>
-        <translation>Domyślna metoda edycji</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="264"/>
+        <location filename="window.py" line="280"/>
         <source>Formatting</source>
         <translation>Formatowanie</translation>
     </message>
     <message>
-        <location filename="window.py" line="302"/>
+        <location filename="window.py" line="317"/>
         <source>Search</source>
         <translation>Wyszukaj</translation>
     </message>
     <message>
-        <location filename="window.py" line="305"/>
+        <location filename="window.py" line="319"/>
         <source>Case sensitively</source>
         <translation>Rozróżnianie wielkości znaków</translation>
     </message>
     <message>
-        <location filename="window.py" line="1125"/>
+        <location filename="window.py" line="1135"/>
         <source>New document</source>
         <translation>Nowy dokument</translation>
     </message>
     <message>
-        <location filename="window.py" line="766"/>
+        <location filename="window.py" line="765"/>
         <source>Please, save the file somewhere.</source>
         <translation>Proszę najpierw zapisać plik.</translation>
     </message>
     <message>
-        <location filename="window.py" line="755"/>
+        <location filename="window.py" line="754"/>
         <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
         <translation>Strony internetowe zapisywane są w katalogu &lt;code&gt;html&lt;/code&gt;.</translation>
     </message>
     <message>
-        <location filename="window.py" line="757"/>
+        <location filename="window.py" line="756"/>
         <source>Show directory</source>
         <translation>Pokaż katalog</translation>
     </message>
     <message>
-        <location filename="window.py" line="884"/>
+        <location filename="window.py" line="880"/>
         <source>Select one or several files to open</source>
         <translation>Zaznacz jeden lub więcej plików do otwarcia</translation>
     </message>
     <message>
-        <location filename="window.py" line="884"/>
+        <location filename="window.py" line="880"/>
         <source>Supported files</source>
         <translation>Obsługiwane pliki</translation>
     </message>
     <message>
-        <location filename="window.py" line="884"/>
+        <location filename="window.py" line="880"/>
         <source>All files (*)</source>
         <translation>Wszystkie pliki (*)</translation>
     </message>
     <message>
-        <location filename="window.py" line="947"/>
+        <location filename="window.py" line="962"/>
         <source>Plain text (*.txt)</source>
         <translation>Zwykły tekst (*.txt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1023"/>
+        <location filename="window.py" line="1038"/>
         <source>Save file</source>
         <translation>Zapisz plik</translation>
     </message>
     <message>
-        <location filename="window.py" line="968"/>
+        <location filename="window.py" line="984"/>
         <source>Cannot save to file because it is read-only!</source>
         <translation>Nie można zapisać pliku, ponieważ jest on tylko do odczytu!</translation>
     </message>
     <message>
-        <location filename="window.py" line="1013"/>
+        <location filename="window.py" line="1029"/>
         <source>Export document to ODT</source>
         <translation>Eksportuj do ODT</translation>
     </message>
     <message>
-        <location filename="window.py" line="1013"/>
+        <location filename="window.py" line="1029"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>Dokumenty OpenDokument (*.odt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1023"/>
+        <location filename="window.py" line="1038"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>Pliki HTML (*.html *.htm)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1044"/>
+        <location filename="window.py" line="1059"/>
         <source>Export document to PDF</source>
         <translation>Eksportuj do PDF</translation>
     </message>
     <message>
-        <location filename="window.py" line="1044"/>
+        <location filename="window.py" line="1059"/>
         <source>PDF files (*.pdf)</source>
         <translation>Pliki PDF (*.pdf)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1060"/>
+        <location filename="window.py" line="1075"/>
         <source>Print document</source>
         <translation>Drukuj dokument</translation>
     </message>
     <message>
-        <location filename="window.py" line="1081"/>
+        <location filename="window.py" line="1096"/>
         <source>Export document</source>
         <translation>Eksportuj dokument</translation>
     </message>
     <message>
-        <location filename="window.py" line="1104"/>
+        <location filename="window.py" line="1114"/>
         <source>Failed to execute the command:</source>
         <translation>Błąd podczas wykonywania komendy:</translation>
     </message>
     <message>
-        <location filename="window.py" line="1181"/>
+        <location filename="window.py" line="1191"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>Dokument został zmieniony.
 Czy chcesz zapisać zmiany?</translation>
     </message>
     <message>
-        <location filename="window.py" line="1214"/>
+        <location filename="window.py" line="1215"/>
         <source>HTML code</source>
         <translation>Kod HTML</translation>
     </message>
     <message>
-        <location filename="window.py" line="1225"/>
+        <location filename="window.py" line="1226"/>
         <source>Simple but powerful editor for Markdown and reStructuredText</source>
         <translation>Prosty, ale potężny edytor Markdown i reStructuredText</translation>
     </message>
     <message>
-        <location filename="window.py" line="1225"/>
+        <location filename="window.py" line="1226"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>Autor: Dmitry Shachnev, 2011&lt;br&gt;
 Tłumaczenie: Kristian Kann, 2012</translation>
     </message>
     <message>
-        <location filename="window.py" line="1225"/>
+        <location filename="window.py" line="1226"/>
         <source>Website</source>
         <translation>Strona internetowa</translation>
     </message>
     <message>
-        <location filename="window.py" line="1225"/>
+        <location filename="window.py" line="1226"/>
         <source>Markdown syntax</source>
         <translation>Składnia Markdown</translation>
     </message>
     <message>
-        <location filename="window.py" line="1225"/>
+        <location filename="window.py" line="1226"/>
         <source>reStructuredText syntax</source>
         <translation>Składnia reStructuredText</translation>
     </message>
     <message>
-        <location filename="window.py" line="950"/>
+        <location filename="window.py" line="965"/>
         <source>%s files</source>
         <comment>Example of final string: Markdown files</comment>
         <translation>Pliki %s</translation>
     </message>
     <message>
-        <location filename="window.py" line="751"/>
+        <location filename="window.py" line="750"/>
         <source>Failed to copy default template, please create template.html manually.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="652"/>
+        <location filename="window.py" line="661"/>
         <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="window.py" line="586"/>
+        <source>Preferences</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="window.py" line="277"/>
+        <source>Default markup</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="window.py" line="106"/>
+        <source>Set encoding</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="window.py" line="937"/>
+        <source>Select file encoding from the list:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
