@@ -1,14 +1,87 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS><TS version="2.0" language="sk_SK" sourcelanguage="en_US">
 <context>
-    <name>LocaleDialog</name>
+    <name>ConfigDialog</name>
     <message>
-        <location filename="window.py" line="17"/>
-        <source>Enter locale name (example: en_US)</source>
-        <translation>Zadajte názov lokalizácie (napr.: sk_SK)</translation>
+        <location filename="config.py" line="24"/>
+        <source>Behavior</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="22"/>
+        <location filename="config.py" line="24"/>
+        <source>Automatically save documents</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Restore window geometry</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Restore live preview state</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Open external links in ReText window</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Open unknown files in plain text mode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Editor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Highlight current line</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Show line numbers</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Tab key inserts spaces</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Tabulation width</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Display right margin at column</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Interface</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Icon theme name</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>LocaleDialog</name>
+    <message>
+        <location filename="dialogs.py" line="34"/>
+        <source>Enter locale name (example: en_US)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="dialogs.py" line="39"/>
         <source>Set as default</source>
         <translation type="unfinished"></translation>
     </message>
@@ -16,388 +89,403 @@
 <context>
     <name>ReTextWindow</name>
     <message>
-        <location filename="window.py" line="71"/>
+        <location filename="window.py" line="92"/>
         <source>File toolbar</source>
         <translation>Panel nástrojov pre súbor</translation>
     </message>
     <message>
-        <location filename="window.py" line="73"/>
+        <location filename="window.py" line="94"/>
         <source>Edit toolbar</source>
         <translation>Panel nástrojov pre úpravy</translation>
     </message>
     <message>
-        <location filename="window.py" line="75"/>
+        <location filename="window.py" line="96"/>
         <source>Search toolbar</source>
         <translation>Panel nástrojov pre vyhľadávanie</translation>
     </message>
     <message>
-        <location filename="window.py" line="80"/>
+        <location filename="window.py" line="100"/>
         <source>New</source>
         <translation>Nový</translation>
     </message>
     <message>
-        <location filename="window.py" line="83"/>
+        <location filename="window.py" line="103"/>
         <source>Open</source>
         <translation>Otvoriť</translation>
     </message>
     <message>
-        <location filename="window.py" line="86"/>
+        <location filename="window.py" line="109"/>
         <source>Save</source>
         <translation>Uložiť</translation>
     </message>
     <message>
-        <location filename="window.py" line="90"/>
+        <location filename="window.py" line="113"/>
         <source>Save as</source>
         <translation>Uložiť ako</translation>
     </message>
     <message>
-        <location filename="window.py" line="92"/>
+        <location filename="window.py" line="115"/>
         <source>Print</source>
         <translation>Tlačiť</translation>
     </message>
     <message>
-        <location filename="window.py" line="95"/>
+        <location filename="window.py" line="118"/>
         <source>Print preview</source>
         <translation>Ukážka pred tlačou</translation>
     </message>
     <message>
-        <location filename="window.py" line="97"/>
+        <location filename="window.py" line="120"/>
         <source>View HTML code</source>
         <translation>Zobraziť HTML kód</translation>
     </message>
     <message>
-        <location filename="window.py" line="98"/>
+        <location filename="window.py" line="121"/>
         <source>Change default font</source>
         <translation>Zmeniť štandardné písmo</translation>
     </message>
     <message>
-        <location filename="window.py" line="99"/>
+        <location filename="window.py" line="122"/>
         <source>Find text</source>
         <translation>Nájsť text</translation>
     </message>
     <message>
-        <location filename="window.py" line="104"/>
+        <location filename="window.py" line="126"/>
         <source>Preview</source>
         <translation>Náhľad</translation>
     </message>
     <message>
-        <location filename="window.py" line="113"/>
+        <location filename="window.py" line="135"/>
         <source>Live preview</source>
         <translation>Priebežný náhľad</translation>
     </message>
     <message>
-        <location filename="window.py" line="115"/>
+        <location filename="window.py" line="137"/>
         <source>Fullscreen mode</source>
         <translation>Celoobrazovkový režim</translation>
     </message>
     <message>
-        <location filename="window.py" line="121"/>
+        <location filename="window.py" line="145"/>
         <source>Quit</source>
         <translation>Quit</translation>
     </message>
     <message>
-        <location filename="window.py" line="124"/>
+        <location filename="window.py" line="148"/>
         <source>Undo</source>
         <translation>Späť</translation>
     </message>
     <message>
-        <location filename="window.py" line="126"/>
+        <location filename="window.py" line="150"/>
         <source>Redo</source>
         <translation>Znova</translation>
     </message>
     <message>
-        <location filename="window.py" line="128"/>
+        <location filename="window.py" line="152"/>
         <source>Copy</source>
         <translation>Kopírovať</translation>
     </message>
     <message>
-        <location filename="window.py" line="130"/>
+        <location filename="window.py" line="154"/>
         <source>Cut</source>
         <translation>Vystrihnúť</translation>
     </message>
     <message>
-        <location filename="window.py" line="132"/>
+        <location filename="window.py" line="156"/>
         <source>Paste</source>
         <translation>Vložiť</translation>
     </message>
     <message>
-        <location filename="window.py" line="141"/>
+        <location filename="window.py" line="166"/>
         <source>Enable</source>
         <translation>Povoliť</translation>
     </message>
     <message>
-        <location filename="window.py" line="142"/>
+        <location filename="window.py" line="167"/>
         <source>Set locale</source>
         <translation>Nastaviť lokalizáciu</translation>
     </message>
     <message>
-        <location filename="window.py" line="143"/>
+        <location filename="window.py" line="168"/>
         <source>Plain text</source>
         <translation>Jednoduchý text</translation>
     </message>
     <message>
-        <location filename="window.py" line="145"/>
+        <location filename="window.py" line="169"/>
         <source>Use WebKit renderer</source>
         <translation>Použiť k vykresľovaniu WebKit</translation>
     </message>
     <message>
-        <location filename="window.py" line="151"/>
+        <location filename="window.py" line="171"/>
         <source>Generate webpages</source>
         <translation>Generovať web stránky</translation>
     </message>
     <message>
-        <location filename="window.py" line="152"/>
+        <location filename="window.py" line="172"/>
         <source>Show</source>
         <translation>Zobraziť</translation>
     </message>
     <message>
-        <location filename="window.py" line="153"/>
+        <location filename="window.py" line="173"/>
         <source>Next</source>
         <translation>Nasledujúci</translation>
     </message>
     <message>
-        <location filename="window.py" line="155"/>
+        <location filename="window.py" line="175"/>
         <source>Previous</source>
         <translation>Predchádzajúci</translation>
     </message>
     <message>
-        <location filename="window.py" line="157"/>
+        <location filename="window.py" line="177"/>
         <source>Get help online</source>
         <translation>Získať online pomoc</translation>
     </message>
     <message>
-        <location filename="window.py" line="166"/>
+        <location filename="window.py" line="182"/>
         <source>About Qt</source>
         <translation>O Qt</translation>
     </message>
     <message>
-        <location filename="window.py" line="187"/>
+        <location filename="window.py" line="202"/>
         <source>Bold</source>
         <translation>Tučné</translation>
     </message>
     <message>
-        <location filename="window.py" line="189"/>
+        <location filename="window.py" line="204"/>
         <source>Italic</source>
         <translation>Kurzíva</translation>
     </message>
     <message>
-        <location filename="window.py" line="191"/>
+        <location filename="window.py" line="206"/>
         <source>Underline</source>
         <translation>Podčiarknuté</translation>
     </message>
     <message>
-        <location filename="window.py" line="199"/>
+        <location filename="window.py" line="214"/>
         <source>Tags</source>
         <translation>Značky</translation>
     </message>
     <message>
-        <location filename="window.py" line="203"/>
+        <location filename="window.py" line="218"/>
         <source>Symbols</source>
         <translation>Symboly</translation>
     </message>
     <message>
-        <location filename="window.py" line="217"/>
+        <location filename="window.py" line="231"/>
         <source>File</source>
         <translation>Súbor</translation>
     </message>
     <message>
-        <location filename="window.py" line="218"/>
+        <location filename="window.py" line="232"/>
         <source>Edit</source>
         <translation>Upraviť</translation>
     </message>
     <message>
-        <location filename="window.py" line="219"/>
+        <location filename="window.py" line="233"/>
         <source>Help</source>
         <translation>Pomocník</translation>
     </message>
     <message>
-        <location filename="window.py" line="222"/>
+        <location filename="window.py" line="236"/>
         <source>Open recent</source>
         <translation>Otvoriť nedávne</translation>
     </message>
     <message>
-        <location filename="window.py" line="225"/>
+        <location filename="window.py" line="239"/>
         <source>Directory</source>
         <translation>Priečinok</translation>
     </message>
     <message>
-        <location filename="window.py" line="232"/>
+        <location filename="window.py" line="247"/>
         <source>Export</source>
         <translation>Export</translation>
     </message>
     <message>
-        <location filename="window.py" line="253"/>
+        <location filename="window.py" line="269"/>
         <source>Spell check</source>
         <translation>Kontrola pravopisu</translation>
     </message>
     <message>
-        <location filename="window.py" line="261"/>
-        <source>Default editing mode</source>
-        <translation>Štandardný režim úprav</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="264"/>
+        <location filename="window.py" line="280"/>
         <source>Formatting</source>
         <translation>Formátovanie</translation>
     </message>
     <message>
-        <location filename="window.py" line="302"/>
+        <location filename="window.py" line="317"/>
         <source>Search</source>
         <translation>Vyhľadávanie</translation>
     </message>
     <message>
-        <location filename="window.py" line="305"/>
+        <location filename="window.py" line="319"/>
         <source>Case sensitively</source>
         <translation>Rozlišovanie veľkosti písmen</translation>
     </message>
     <message>
-        <location filename="window.py" line="1125"/>
+        <location filename="window.py" line="1135"/>
         <source>New document</source>
         <translation>Nový dokument</translation>
     </message>
     <message>
-        <location filename="window.py" line="766"/>
+        <location filename="window.py" line="765"/>
         <source>Please, save the file somewhere.</source>
         <translation>Uložte prosím niekam súbor.</translation>
     </message>
     <message>
-        <location filename="window.py" line="755"/>
+        <location filename="window.py" line="754"/>
         <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
         <translation>Web stránky uložené do priečinku &lt;code&gt;html&lt;/code&gt;.</translation>
     </message>
     <message>
-        <location filename="window.py" line="757"/>
+        <location filename="window.py" line="756"/>
         <source>Show directory</source>
         <translation>Zobraziť priečinok</translation>
     </message>
     <message>
-        <location filename="window.py" line="884"/>
+        <location filename="window.py" line="880"/>
         <source>Select one or several files to open</source>
         <translation>Vyberte jeden alebo viac súborov k otvoreniu</translation>
     </message>
     <message>
-        <location filename="window.py" line="884"/>
+        <location filename="window.py" line="880"/>
         <source>Supported files</source>
         <translation>Podporované súbory</translation>
     </message>
     <message>
-        <location filename="window.py" line="884"/>
+        <location filename="window.py" line="880"/>
         <source>All files (*)</source>
         <translation>Všetky súbory (*.*)</translation>
     </message>
     <message>
-        <location filename="window.py" line="947"/>
+        <location filename="window.py" line="962"/>
         <source>Plain text (*.txt)</source>
         <translation>Jednoduchý text (*.txt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1023"/>
+        <location filename="window.py" line="1038"/>
         <source>Save file</source>
         <translation>Uložiť súbor</translation>
     </message>
     <message>
-        <location filename="window.py" line="968"/>
+        <location filename="window.py" line="984"/>
         <source>Cannot save to file because it is read-only!</source>
         <translation>Nie je možné uložiť, pretože súbor je len nna čítanie!</translation>
     </message>
     <message>
-        <location filename="window.py" line="1013"/>
+        <location filename="window.py" line="1029"/>
         <source>Export document to ODT</source>
         <translation>Exportovať dokument do ODT</translation>
     </message>
     <message>
-        <location filename="window.py" line="1013"/>
+        <location filename="window.py" line="1029"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>OpenDocument textové súbory (*.odt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1023"/>
+        <location filename="window.py" line="1038"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>HTML súbory (*.html *.htm)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1044"/>
+        <location filename="window.py" line="1059"/>
         <source>Export document to PDF</source>
         <translation>Exportovať dokument do PDF</translation>
     </message>
     <message>
-        <location filename="window.py" line="1044"/>
+        <location filename="window.py" line="1059"/>
         <source>PDF files (*.pdf)</source>
         <translation>PDF súbory (*.pdf)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1060"/>
+        <location filename="window.py" line="1075"/>
         <source>Print document</source>
         <translation>Tlačiť dokument</translation>
     </message>
     <message>
-        <location filename="window.py" line="1081"/>
+        <location filename="window.py" line="1096"/>
         <source>Export document</source>
         <translation>Exportovať dokument</translation>
     </message>
     <message>
-        <location filename="window.py" line="1104"/>
+        <location filename="window.py" line="1114"/>
         <source>Failed to execute the command:</source>
         <translation>Nepodarilo sa spustiť príkaz:</translation>
     </message>
     <message>
-        <location filename="window.py" line="1181"/>
+        <location filename="window.py" line="1191"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>Dokument bol zmenený.
 Chcete uložiť vaše zmeny?</translation>
     </message>
     <message>
-        <location filename="window.py" line="1214"/>
+        <location filename="window.py" line="1215"/>
         <source>HTML code</source>
         <translation>HTML kód</translation>
     </message>
     <message>
-        <location filename="window.py" line="1225"/>
+        <location filename="window.py" line="1226"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>Autor: Dmitry Shachnev, 2011</translation>
     </message>
     <message>
-        <location filename="window.py" line="1225"/>
+        <location filename="window.py" line="1226"/>
         <source>Website</source>
         <translation>Webová stránka</translation>
     </message>
     <message>
-        <location filename="window.py" line="1225"/>
+        <location filename="window.py" line="1226"/>
         <source>Markdown syntax</source>
         <translation>Markdown syntax</translation>
     </message>
     <message>
-        <location filename="window.py" line="158"/>
+        <location filename="window.py" line="178"/>
         <source>About %s</source>
         <comment>Example of final string: About ReText</comment>
         <translation>O %s</translation>
     </message>
     <message>
-        <location filename="window.py" line="751"/>
+        <location filename="window.py" line="750"/>
         <source>Failed to copy default template, please create template.html manually.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="950"/>
+        <location filename="window.py" line="965"/>
         <source>%s files</source>
         <comment>Example of final string: Markdown files</comment>
         <translation>Súbory %s</translation>
     </message>
     <message>
-        <location filename="window.py" line="1225"/>
+        <location filename="window.py" line="1226"/>
         <source>Simple but powerful editor for Markdown and reStructuredText</source>
         <translation>Jednoduchý a pritom efektívny editor pre Markdown a reStructuredText</translation>
     </message>
     <message>
-        <location filename="window.py" line="1225"/>
+        <location filename="window.py" line="1226"/>
         <source>reStructuredText syntax</source>
         <translation>reStructuredText syntax</translation>
     </message>
     <message>
-        <location filename="window.py" line="652"/>
+        <location filename="window.py" line="661"/>
         <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="window.py" line="277"/>
+        <source>Default markup</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="window.py" line="586"/>
+        <source>Preferences</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="window.py" line="106"/>
+        <source>Set encoding</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="window.py" line="937"/>
+        <source>Select file encoding from the list:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
