@@ -1,401 +1,489 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS><TS version="2.0" language="zh_CN" sourcelanguage="">
+<context>
+    <name>ConfigDialog</name>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Behavior</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Automatically save documents</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Restore window geometry</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Restore live preview state</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Open external links in ReText window</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Open unknown files in plain text mode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Editor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Highlight current line</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Show line numbers</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Tab key inserts spaces</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Tabulation width</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Display right margin at column</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Interface</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="24"/>
+        <source>Icon theme name</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>LocaleDialog</name>
     <message>
-        <location filename="window.py" line="17"/>
+        <location filename="dialogs.py" line="34"/>
         <source>Enter locale name (example: en_US)</source>
         <translation>输入语言名称 (例如: en_US)</translation>
     </message>
     <message>
-        <location filename="window.py" line="22"/>
+        <location filename="dialogs.py" line="39"/>
         <source>Set as default</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>ReTextWindow</name>
-    <message>
-        <location filename="window.py" line="83"/>
-        <source>Open</source>
-        <translation>打开</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="86"/>
-        <source>Save</source>
-        <translation>保存</translation>
-    </message>
     <message>
         <location filename="window.py" line="92"/>
-        <source>Print</source>
-        <translation>打印</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="104"/>
-        <source>Preview</source>
-        <translation>预览</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="199"/>
-        <source>Tags</source>
-        <translation>标签</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="203"/>
-        <source>Symbols</source>
-        <translation>符号</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1023"/>
-        <source>HTML files (*.html *.htm)</source>
-        <translation>HTML 文件 (*.html *.htm)</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1023"/>
-        <source>Save file</source>
-        <translation>保存文件</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="90"/>
-        <source>Save as</source>
-        <translation>另存文件</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="121"/>
-        <source>Quit</source>
-        <translation>退出</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="166"/>
-        <source>About Qt</source>
-        <translation>关于 Qt</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="217"/>
-        <source>File</source>
-        <translation>文件</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="218"/>
-        <source>Edit</source>
-        <translation>编辑</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="219"/>
-        <source>Help</source>
-        <translation>帮助</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="232"/>
-        <source>Export</source>
-        <translation>导出</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="71"/>
         <source>File toolbar</source>
         <translation>文件工具栏</translation>
     </message>
     <message>
-        <location filename="window.py" line="73"/>
+        <location filename="window.py" line="94"/>
         <source>Edit toolbar</source>
         <translation>编辑工具栏</translation>
     </message>
     <message>
-        <location filename="window.py" line="1044"/>
-        <source>Export document to PDF</source>
-        <translation>导出文件到 PDF</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1044"/>
-        <source>PDF files (*.pdf)</source>
-        <translation>PDF 文件 (*.pdf)</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1181"/>
-        <source>The document has been modified.
-Do you want to save your changes?</source>
-        <translation>文件已更改，确认保存吗？</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="124"/>
-        <source>Undo</source>
-        <translation>取消</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="126"/>
-        <source>Redo</source>
-        <translation>重做</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="128"/>
-        <source>Copy</source>
-        <translation>复制</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="130"/>
-        <source>Cut</source>
-        <translation>剪切</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="132"/>
-        <source>Paste</source>
-        <translation>粘贴</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1125"/>
-        <source>New document</source>
-        <translation>新文件</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="884"/>
-        <source>All files (*)</source>
-        <translation>全部文件 (*)</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="80"/>
-        <source>New</source>
-        <translation>新建</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="222"/>
-        <source>Open recent</source>
-        <translation>打开最近使用</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="143"/>
-        <source>Plain text</source>
-        <translation>普通文本</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1013"/>
-        <source>OpenDocument text files (*.odt)</source>
-        <translation>Libreoffice 文件 (*.odt)</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1013"/>
-        <source>Export document to ODT</source>
-        <translation>导出文件到 ODT</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="97"/>
-        <source>View HTML code</source>
-        <translation>查看 HTML 代码</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1214"/>
-        <source>HTML code</source>
-        <translation>HTML 代码</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="95"/>
-        <source>Print preview</source>
-        <translation>打印预览</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1060"/>
-        <source>Print document</source>
-        <translation>打印文件</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="113"/>
-        <source>Live preview</source>
-        <translation>实时预览</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="755"/>
-        <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
-        <translation>网页保存在 &lt;code&gt;html&lt;/code&gt; 文件夹。</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="766"/>
-        <source>Please, save the file somewhere.</source>
-        <translation>请，保存到别的地方呦！</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="151"/>
-        <source>Generate webpages</source>
-        <translation>生成网页</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="947"/>
-        <source>Plain text (*.txt)</source>
-        <translation>普通文本文档 (*.txt)</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="152"/>
-        <source>Show</source>
-        <translation>显示</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="225"/>
-        <source>Directory</source>
-        <translation>目录</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="884"/>
-        <source>Supported files</source>
-        <translation>支持的文件类型</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="98"/>
-        <source>Change default font</source>
-        <translation>改变默认字体</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1081"/>
-        <source>Export document</source>
-        <translation>导出文件</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="141"/>
-        <source>Enable</source>
-        <translation>激活</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="142"/>
-        <source>Set locale</source>
-        <translation>选择界面语言</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="253"/>
-        <source>Spell check</source>
-        <translation>拼写检查</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="115"/>
-        <source>Fullscreen mode</source>
-        <translation>全屏模式</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="75"/>
+        <location filename="window.py" line="96"/>
         <source>Search toolbar</source>
         <translation>搜索工具栏</translation>
     </message>
     <message>
-        <location filename="window.py" line="99"/>
+        <location filename="window.py" line="100"/>
+        <source>New</source>
+        <translation>新建</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="103"/>
+        <source>Open</source>
+        <translation>打开</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="109"/>
+        <source>Save</source>
+        <translation>保存</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="113"/>
+        <source>Save as</source>
+        <translation>另存文件</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="115"/>
+        <source>Print</source>
+        <translation>打印</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="118"/>
+        <source>Print preview</source>
+        <translation>打印预览</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="120"/>
+        <source>View HTML code</source>
+        <translation>查看 HTML 代码</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="121"/>
+        <source>Change default font</source>
+        <translation>改变默认字体</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="122"/>
         <source>Find text</source>
         <translation>查找文本</translation>
     </message>
     <message>
-        <location filename="window.py" line="153"/>
+        <location filename="window.py" line="126"/>
+        <source>Preview</source>
+        <translation>预览</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="135"/>
+        <source>Live preview</source>
+        <translation>实时预览</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="137"/>
+        <source>Fullscreen mode</source>
+        <translation>全屏模式</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="145"/>
+        <source>Quit</source>
+        <translation>退出</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="148"/>
+        <source>Undo</source>
+        <translation>取消</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="150"/>
+        <source>Redo</source>
+        <translation>重做</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="152"/>
+        <source>Copy</source>
+        <translation>复制</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="154"/>
+        <source>Cut</source>
+        <translation>剪切</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="156"/>
+        <source>Paste</source>
+        <translation>粘贴</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="166"/>
+        <source>Enable</source>
+        <translation>激活</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="167"/>
+        <source>Set locale</source>
+        <translation>选择界面语言</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="168"/>
+        <source>Plain text</source>
+        <translation>普通文本</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="169"/>
+        <source>Use WebKit renderer</source>
+        <translation>使用WebKit渲染</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="171"/>
+        <source>Generate webpages</source>
+        <translation>生成网页</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="172"/>
+        <source>Show</source>
+        <translation>显示</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="173"/>
         <source>Next</source>
         <translation>下一项</translation>
     </message>
     <message>
-        <location filename="window.py" line="155"/>
+        <location filename="window.py" line="175"/>
         <source>Previous</source>
         <translation>上一项</translation>
     </message>
     <message>
-        <location filename="window.py" line="261"/>
-        <source>Default editing mode</source>
-        <translation>默认编辑模式</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="302"/>
-        <source>Search</source>
-        <translation>搜索</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="305"/>
-        <source>Case sensitively</source>
-        <translation>对大小写敏感</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1225"/>
-        <source>Author: Dmitry Shachnev, 2011</source>
-        <translation>作者: Dmitry Shachnev, 2011</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1225"/>
-        <source>Website</source>
-        <translation>网站</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1225"/>
-        <source>Markdown syntax</source>
-        <translation>Markdown 语法</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1225"/>
-        <source>reStructuredText syntax</source>
-        <translation>reStructuredText 语法</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1225"/>
-        <source>Simple but powerful editor for Markdown and reStructuredText</source>
-        <translation>简单高效的 Markdown 与 reStructuredText 编辑器</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="884"/>
-        <source>Select one or several files to open</source>
-        <translation>选择一个或多个文件以打开</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="157"/>
+        <location filename="window.py" line="177"/>
         <source>Get help online</source>
         <translation>在线获取帮助（英文）</translation>
     </message>
     <message>
-        <location filename="window.py" line="757"/>
-        <source>Show directory</source>
-        <translation>显示文件夹</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="968"/>
-        <source>Cannot save to file because it is read-only!</source>
-        <translation>不能保存文件因为它是只读的！</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="187"/>
-        <source>Bold</source>
-        <translation>加粗</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="189"/>
-        <source>Italic</source>
-        <translation>傾斜</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="191"/>
-        <source>Underline</source>
-        <translation>下划线</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="264"/>
-        <source>Formatting</source>
-        <translation>格式</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="158"/>
+        <location filename="window.py" line="178"/>
         <source>About %s</source>
         <comment>Example of final string: About ReText</comment>
         <translation>关于 %s</translation>
     </message>
     <message>
-        <location filename="window.py" line="145"/>
-        <source>Use WebKit renderer</source>
-        <translation>使用WebKit渲染</translation>
+        <location filename="window.py" line="182"/>
+        <source>About Qt</source>
+        <translation>关于 Qt</translation>
     </message>
     <message>
-        <location filename="window.py" line="1104"/>
-        <source>Failed to execute the command:</source>
-        <translation>不能执行命令:</translation>
+        <location filename="window.py" line="202"/>
+        <source>Bold</source>
+        <translation>加粗</translation>
     </message>
     <message>
-        <location filename="window.py" line="950"/>
+        <location filename="window.py" line="204"/>
+        <source>Italic</source>
+        <translation>傾斜</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="206"/>
+        <source>Underline</source>
+        <translation>下划线</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="214"/>
+        <source>Tags</source>
+        <translation>标签</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="218"/>
+        <source>Symbols</source>
+        <translation>符号</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="231"/>
+        <source>File</source>
+        <translation>文件</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="232"/>
+        <source>Edit</source>
+        <translation>编辑</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="233"/>
+        <source>Help</source>
+        <translation>帮助</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="236"/>
+        <source>Open recent</source>
+        <translation>打开最近使用</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="239"/>
+        <source>Directory</source>
+        <translation>目录</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="247"/>
+        <source>Export</source>
+        <translation>导出</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="269"/>
+        <source>Spell check</source>
+        <translation>拼写检查</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="280"/>
+        <source>Formatting</source>
+        <translation>格式</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="317"/>
+        <source>Search</source>
+        <translation>搜索</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="319"/>
+        <source>Case sensitively</source>
+        <translation>对大小写敏感</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1135"/>
+        <source>New document</source>
+        <translation>新文件</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="661"/>
+        <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="window.py" line="765"/>
+        <source>Please, save the file somewhere.</source>
+        <translation>请，保存到别的地方呦！</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="750"/>
+        <source>Failed to copy default template, please create template.html manually.</source>
+        <translation>未能加载默认模板，请您手动创建 template.html</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="754"/>
+        <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
+        <translation>网页保存在 &lt;code&gt;html&lt;/code&gt; 文件夹。</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="756"/>
+        <source>Show directory</source>
+        <translation>显示文件夹</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="880"/>
+        <source>Select one or several files to open</source>
+        <translation>选择一个或多个文件以打开</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="880"/>
+        <source>Supported files</source>
+        <translation>支持的文件类型</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="880"/>
+        <source>All files (*)</source>
+        <translation>全部文件 (*)</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="962"/>
+        <source>Plain text (*.txt)</source>
+        <translation>普通文本文档 (*.txt)</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="965"/>
         <source>%s files</source>
         <comment>Example of final string: Markdown files</comment>
         <translation>%s 文件</translation>
     </message>
     <message>
-        <location filename="window.py" line="751"/>
-        <source>Failed to copy default template, please create template.html manually.</source>
+        <location filename="window.py" line="1038"/>
+        <source>Save file</source>
+        <translation>保存文件</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="984"/>
+        <source>Cannot save to file because it is read-only!</source>
+        <translation>不能保存文件因为它是只读的！</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1029"/>
+        <source>Export document to ODT</source>
+        <translation>导出文件到 ODT</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1029"/>
+        <source>OpenDocument text files (*.odt)</source>
+        <translation>OpenDocument 文本文件 (*.odt)</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1038"/>
+        <source>HTML files (*.html *.htm)</source>
+        <translation>HTML 文件 (*.html *.htm)</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1059"/>
+        <source>Export document to PDF</source>
+        <translation>导出文件到 PDF</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1059"/>
+        <source>PDF files (*.pdf)</source>
+        <translation>PDF 文件 (*.pdf)</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1075"/>
+        <source>Print document</source>
+        <translation>打印文件</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1096"/>
+        <source>Export document</source>
+        <translation>导出文件</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1114"/>
+        <source>Failed to execute the command:</source>
+        <translation>不能执行命令:</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1191"/>
+        <source>The document has been modified.
+Do you want to save your changes?</source>
+        <translation>文件已更改，确认保存吗？</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1215"/>
+        <source>HTML code</source>
+        <translation>HTML 代码</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1226"/>
+        <source>Simple but powerful editor for Markdown and reStructuredText</source>
+        <translation>简单高效的 Markdown 与 ReStructuredText 编辑器</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1226"/>
+        <source>Author: Dmitry Shachnev, 2011</source>
+        <translation>作者: Dmitry Shachnev, 2011</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1226"/>
+        <source>Website</source>
+        <translation>网站</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1226"/>
+        <source>Markdown syntax</source>
+        <translation>Markdown 语法</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1226"/>
+        <source>reStructuredText syntax</source>
+        <translation>reStructuredText 语法</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="106"/>
+        <source>Set encoding</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="652"/>
-        <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
+        <location filename="window.py" line="586"/>
+        <source>Preferences</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="window.py" line="277"/>
+        <source>Default markup</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="window.py" line="937"/>
+        <source>Select file encoding from the list:</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
