@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 
 # ReText
-# Copyright 2011-2012 Dmitry Shachnev
+# Copyright 2011-2013 Dmitry Shachnev
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,13 +19,22 @@
 # MA 02110-1301, USA.
 
 import sys
-from ReText import *
+import signal
+from ReText import QtCore, QtWidgets, QtWebKit, datadirs, globalSettings
 from ReText.window import ReTextWindow
 
+(QFile, QFileInfo, QIODevice, QLibraryInfo, QLocale, QTextStream,
+ QTranslator) = (QtCore.QFile, QtCore.QFileInfo, QtCore.QIODevice,
+ QtCore.QLibraryInfo, QtCore.QLocale, QtCore.QTextStream, QtCore.QTranslator)
+QApplication = QtWidgets.QApplication
+QWebSettings = QtWebKit.QWebSettings
+
 def main():
 	app = QApplication(sys.argv)
 	app.setOrganizationName("ReText project")
 	app.setApplicationName("ReText")
+	if hasattr(app, 'setApplicationDisplayName'):
+		app.setApplicationDisplayName("ReText")
 	RtTranslator = QTranslator()
 	for path in datadirs:
 		if RtTranslator.load('retext_'+QLocale.system().name(), path+'/locale'):
@@ -34,23 +43,21 @@ def main():
 	QtTranslator.load("qt_"+QLocale.system().name(), QLibraryInfo.location(QLibraryInfo.TranslationsPath))
 	app.installTranslator(RtTranslator)
 	app.installTranslator(QtTranslator)
-	if settings.contains('appStyleSheet'):
-		stylename = readFromSettings('appStyleSheet', str)
-		sheetfile = QFile(stylename)
+	if globalSettings.appStyleSheet:
+		sheetfile = QFile(globalSettings.appStyleSheet)
 		sheetfile.open(QIODevice.ReadOnly)
 		app.setStyleSheet(QTextStream(sheetfile).readAll())
 		sheetfile.close()
+	# A work-around for https://bugs.webkit.org/show_bug.cgi?id=114618
+	webSettings = QWebSettings.globalSettings()
+	webSettings.setFontFamily(QWebSettings.FixedFont, 'monospace')
 	window = ReTextWindow()
 	window.show()
 	fileNames = [QFileInfo(arg).canonicalFilePath() for arg in sys.argv[1:]]
 	for fileName in fileNames:
-		try:
-			fileName = QString.fromUtf8(fileName)
-		except:
-			# Not needed for Python 3
-			pass
 		if QFile.exists(fileName):
 			window.openFileWrapper(fileName)
+	signal.signal(signal.SIGINT, lambda sig, frame: window.close())
 	sys.exit(app.exec_())
 
 if __name__ == '__main__':
